@@ -57,7 +57,20 @@ require_once 'TestCase.php';
  */
 class ImportKeyTestCase extends Crypt_GPG_TestCase
 {
-    // string
+    // set up
+    // {{{ setUp()
+
+    public function setUp()
+    {
+        parent::setUp();
+
+        // In GnuPG 2.1 first operation on a keyring in v1 format
+        // will cause format update and several IMPORT_OK responses
+        // This way we clean the state first
+        $this->gpg->getKeys();
+    }
+
+    // }}}
     // {{{ testImportKey_private()
 
     /**
@@ -65,6 +78,9 @@ class ImportKeyTestCase extends Crypt_GPG_TestCase
      */
     public function testImportKey_private()
     {
+        // Note: Some of GnuPG 2.1.x versions return different private_imported
+        // and private_uchanged values, bug? GnuPG 2.1.15 returns 1 as expected.
+
         $expectedResult = array(
             'fingerprint'       => 'F83118CB6F5892DC1C3E936DABA81EF54E8C0DEB',
             'fingerprints'      => array('F83118CB6F5892DC1C3E936DABA81EF54E8C0DEB'),
@@ -243,9 +259,9 @@ TEXT;
             'fingerprint'       => 'F83118CB6F5892DC1C3E936DABA81EF54E8C0DEB',
             'fingerprints'      => array('F83118CB6F5892DC1C3E936DABA81EF54E8C0DEB'),
             'public_imported'   => 0,
-            'public_unchanged'  => 0,
+            'public_unchanged'  => version_compare($this->gpg->getVersion(), '2.1.0', 'ge') ? 1 : 0,
             'private_imported'  => 0,
-            'private_unchanged' => 1
+            'private_unchanged'  => 1,
         );
 
         $this->assertEquals($expectedResult, $result);
@@ -352,8 +368,6 @@ TEXT;
     }
 
     // }}}
-
-    // file
     // {{{ testImportKeyFile_private()
 
     /**
@@ -427,9 +441,9 @@ TEXT;
             'fingerprint'       => 'F83118CB6F5892DC1C3E936DABA81EF54E8C0DEB',
             'fingerprints'      => array('F83118CB6F5892DC1C3E936DABA81EF54E8C0DEB'),
             'public_imported'   => 0,
-            'public_unchanged'  => 0,
+            'public_unchanged'  => version_compare($this->gpg->getVersion(), '2.1.0', 'ge') ? 1 : 0,
             'private_imported'  => 0,
-            'private_unchanged' => 1
+            'private_unchanged'  => 1,
         );
 
         $this->assertEquals($expectedResult, $result);
