@@ -3,7 +3,7 @@
 /* vim: set expandtab tabstop=4 shiftwidth=4 softtabstop=4: */
 
 /**
- * PHPUnit AllTests suite for the Services_Akismet2 package.
+ * PHPUnit AllTests suite for the Crypt_GPG package.
  *
  * These tests require the PHPUnit 3.6 or greater package to be installed.
  * PHPUnit is installable using PEAR. See the
@@ -31,7 +31,6 @@
  * @author    Michael Gauthier <mike@silverorange.com>
  * @copyright 2005-2013 silverorange
  * @license   http://www.gnu.org/copyleft/lesser.html LGPL License 2.1
- * @version   CVS: $Id$
  * @link      http://pear.php.net/package/Crypt_GPG
  */
 
@@ -76,7 +75,7 @@ require_once 'Crypt/GPG/Signature.php';
  *    A public-private key pair that has multiple encrypting subkeys. The
  *    first subkey is an ELG-E key. The second is an RSA key.
  */
-abstract class Crypt_GPG_TestCase extends PHPUnit_Framework_TestCase
+abstract class Crypt_GPG_TestCase extends PHPUnit\Framework\TestCase
 {
     // {{{ class constants
 
@@ -96,10 +95,23 @@ abstract class Crypt_GPG_TestCase extends PHPUnit_Framework_TestCase
 
     protected function getOptions()
     {
-        return array(
-            'homedir' => dirname(__FILE__) . '/' . self::HOMEDIR,
-//            'debug'   => true
+        $config = array(
+            'homedir' => __DIR__ . '/' . self::HOMEDIR,
+//            'binary' => '/usr/bin/gpg2',
+//            'agent'  => '/usr/bin/gpg-agent',
+//            'gpgconf'  => '/usr/local/bin/gpgconf',
+//            'cipher-algo' => 'AES256',
+//            'digest-algo' => 'SHA512',
+//            'compress-algo' => 'zip',
+//            'debug'  => true,
+//            'options' => array(),
         );
+
+        if ($binary = getenv('TESTS_GPG_BINARY')) {
+            $config['binary'] = $binary;
+        }
+
+        return $config;
     }
 
     // }}}
@@ -110,7 +122,7 @@ abstract class Crypt_GPG_TestCase extends PHPUnit_Framework_TestCase
     public function setUp()
     {
         // load test configuration file if it exists
-        $configFilename = dirname(__FILE__).'/config.php';
+        $configFilename = __DIR__ . '/config.php';
         if (file_exists($configFilename)) {
             include $configFilename;
 
@@ -135,7 +147,6 @@ abstract class Crypt_GPG_TestCase extends PHPUnit_Framework_TestCase
             $this->config['enable-key-generation'] = false;
         }
 
-
         $this->_setUpKeyring();
         $this->_setUpTempdir();
 
@@ -518,7 +529,7 @@ NfH1l4n9va0EcqKEwb25
 TEXT;
         // }}}
 
-        $directoryName = dirname(__FILE__) . '/' . self::HOMEDIR;
+        $directoryName = __DIR__ . '/' . self::HOMEDIR;
         if (!file_exists($directoryName)) {
             mkdir($directoryName);
         }
@@ -547,15 +558,13 @@ TEXT;
 
     private function _setUpTempdir()
     {
-        $directoryName = dirname(__FILE__) . '/' . self::TEMPDIR;
+        $directoryName = __DIR__ . '/' . self::TEMPDIR;
         if (!file_exists($directoryName)) {
             mkdir($directoryName);
         }
     }
 
     // }}}
-
-    // tear down
     // {{{ tearDown()
 
     public function tearDown()
@@ -571,33 +580,39 @@ TEXT;
 
     private function _tearDownKeyring()
     {
-        $filenames = array(
-            $this->getKeyringFilename('pubring.gpg~'),
-            $this->getKeyringFilename('secring.gpg~'),
-            $this->getKeyringFilename('trustdb.gpg~'),
-            $this->getKeyringFilename('pubring.gpg'),
-            $this->getKeyringFilename('secring.gpg'),
-            $this->getKeyringFilename('trustdb.gpg'),
-            $this->getKeyringFilename('random_seed')
-        );
-
-        foreach ($filenames as $filename) {
-            if (file_exists($filename)) {
-                unlink($filename);
-            }
-        }
-
         $dirnames = array(
-            $this->getKeyringFilename('private-keys-v1.d')
+            $this->getKeyringFilename('private-keys-v1.d'),
+            $this->getKeyringFilename('openpgp-revocs.d')
         );
 
         foreach ($dirnames as $dirname) {
             if (file_exists($dirname)) {
+                $iterator = new DirectoryIterator($dirname);
+                foreach ($iterator as $file) {
+                    if (!$file->isDot()) {
+                        $filename = $dirname . '/' . $file->getFilename();
+                        if (file_exists($filename)) {
+                            unlink($filename);
+                        }
+                    }
+                }
                 rmdir($dirname);
             }
         }
 
-        rmdir(dirname(__FILE__) . '/' . self::HOMEDIR);
+        $homedir  = __DIR__ . '/' . self::HOMEDIR;
+        $iterator = new DirectoryIterator($homedir);
+
+        foreach ($iterator as $file) {
+            if (!$file->isDot()) {
+                $filename = $homedir . '/' . $file->getFilename();
+                if (file_exists($filename)) {
+                    unlink($filename);
+                }
+            }
+        }
+
+        rmdir($homedir);
     }
 
     // }}}
@@ -605,17 +620,19 @@ TEXT;
 
     private function _tearDownTempdir()
     {
-        $directoryName = dirname(__FILE__) . '/' . self::TEMPDIR;
+        $directoryName = __DIR__ . '/' . self::TEMPDIR;
 
         // remove temporary files and temporary directory
         $iterator = new DirectoryIterator($directoryName);
         foreach ($iterator as $file) {
             if (!$file->isDot()) {
                 $filename = $this->getTempFilename($file->getFilename());
-                if (is_dir($filename)) {
-                    rmdir($filename);
-                } else {
-                    unlink($filename);
+                if (file_exists($filename)) {
+                    if (is_dir($filename)) {
+                        rmdir($filename);
+                    } else {
+                        unlink($filename);
+                    }
                 }
             }
         }
@@ -624,8 +641,6 @@ TEXT;
     }
 
     // }}}
-
-    // file related helper methods
     // {{{ getMd5Sum()
 
     protected function getMd5Sum($filename)
@@ -645,7 +660,7 @@ TEXT;
 
     protected function getKeyringFilename($filename)
     {
-        return dirname(__FILE__) . '/'. self::HOMEDIR . '/' . $filename;
+        return __DIR__ . '/'. self::HOMEDIR . '/' . $filename;
     }
 
     // }}}
@@ -653,7 +668,7 @@ TEXT;
 
     protected function getDataFilename($filename)
     {
-        return dirname(__FILE__) . '/'. self::DATADIR . '/' . $filename;
+        return __DIR__ . '/'. self::DATADIR . '/' . $filename;
     }
 
     // }}}
@@ -661,12 +676,10 @@ TEXT;
 
     protected function getTempFilename($filename)
     {
-        return dirname(__FILE__) . '/' . self::TEMPDIR . '/' . $filename;
+        return __DIR__ . '/' . self::TEMPDIR . '/' . $filename;
     }
 
     // }}}
-
-    // signature related assertions
     // {{{ assertDecryptAndVerifyResultsEquals()
 
     protected function assertDecryptAndVerifyResultsEquals(
